@@ -1,6 +1,4 @@
 
-from __future__ import (absolute_import, division, print_function, unicode_literals)
-
 import sys, os, json, time, requests, csv
 from datetime import datetime
 import pandas as pd
@@ -314,7 +312,7 @@ def parseEvents(events):
             try:
                 events = json.loads(events)
             except json.decoder.JSONDecodeError:
-                raise EigenException("Could not parse input")
+                raise EigenException("Could not parse input, enter the path to a file, or a json/dict object")
     try:
         events = events["events"]
     except:
